@@ -566,6 +566,34 @@ class BasePeople(sc.prettyobj):
         self.init_contacts() # Initialize the contacts
         self.infection_log = [] # Record of infections - keys for ['source','target','date','layer']
 
+        # Set person properties -- all floats except for UID
+        for key in self.meta.person:
+            if key == 'uid':
+                self[key] = np.arange(self.pop_size, dtype=cvd.default_int)
+            else:
+                self[key] = np.full(self.pop_size, np.nan, dtype=cvd.default_float)
+
+        # Set health states -- only susceptible is true by default -- booleans
+        for key in self.meta.states:
+            if key == 'susceptible':
+                self[key] = np.full(self.pop_size, True, dtype=bool)
+            else:
+                self[key] = np.full(self.pop_size, False, dtype=bool)
+
+        # Set dates and durations -- both floats
+        for key in self.meta.dates + self.meta.durs:
+            self[key] = np.full(self.pop_size, np.nan, dtype=cvd.default_float)
+
+        # Store the dtypes used in a flat dict
+        self._dtypes = {key:self[key].dtype for key in self.keys()} # Assign all to float by default
+        self._lock = True # Stop further keys from being set (does not affect attributes)
+
+        # Store flows to be computed during simulation
+        self.flows = {key:0 for key in cvd.new_result_flows}
+
+        # Although we have called init(), we still need to call initialize()
+        self.initialized = False
+
         return
 
 
@@ -665,12 +693,29 @@ class BasePeople(sc.prettyobj):
         return (self[key]==0).sum()
 
 
-    def keys(self, which=None):
-        ''' Returns the name of the states '''
-        if which is None:
-            return self.meta.all_states[:]
-        else:
-            return getattr(self.meta, which)[:]
+    def keys(self):
+        ''' Returns keys for all properties of the people object '''
+        return self.meta.all_states[:]
+
+
+    def person_keys(self):
+        ''' Returns keys specific to a person (e.g., their age) '''
+        return self.meta.person[:]
+
+
+    def state_keys(self):
+        ''' Returns keys for different states of a person (e.g., symptomatic) '''
+        return self.meta.states[:]
+
+
+    def date_keys(self):
+        ''' Returns keys for different event dates (e.g., date a person became symptomatic) '''
+        return self.meta.dates[:]
+
+
+    def dur_keys(self):
+        ''' Returns keys for different durations (e.g., the duration from exposed to infectious) '''
+        return self.meta.durs[:]
 
 
     def layer_keys(self):
@@ -957,12 +1002,12 @@ class Contacts(FlexDict):
 
 
 class Layer(FlexDict):
-    ''' A tiny class holding a single layer of contacts '''
+    ''' A small class holding a single layer of contacts '''
 
     def __init__(self, **kwargs):
         self.meta = {
-            'p1':    cvd.default_int, # Person 1
-            'p2':    cvd.default_int,  # Person 2
+            'p1':    cvd.default_int,   # Person 1
+            'p2':    cvd.default_int,   # Person 2
             'beta':  cvd.default_float, # Default transmissibility for this contact type
         }
         self.basekey = 'p1' # Assign a base key for calculating lengths and performing other operations
@@ -993,6 +1038,11 @@ class Layer(FlexDict):
         return output
 
 
+    def meta_keys(self):
+        ''' Return the keys for the layer's meta information -- i.e., p1, p2, beta '''
+        return self.meta.keys()
+
+
     def validate(self):
         ''' Check the integrity of the layer: right types, right lengths '''
         n = len(self[self.basekey])
@@ -1003,6 +1053,38 @@ class Layer(FlexDict):
         return
 
 
+    def pop_inds(self, inds):
+        '''
+        "Pop" the specified indices from the edgelist and return them as a dict.
+        Returns in the right format to be used with layer.append().
+
+        Args:
+            inds (int, array, slice): the indices to be removed
+        '''
+        output = {}
+        for key in self.meta_keys():
+            output[key] = self[key][inds] # Copy to the output object
+            self[key] = np.delete(self[key], inds) # Remove from the original
+        return output
+
+
+    def append(self, contacts):
+        '''
+        Append contacts to the current layer.
+
+        Args:
+            contacts (dict): a dictionary of arrays with keys p1,p2,beta, as returned from layer.pop_inds()
+        '''
+        for key in self.keys():
+            new_arr = contacts[key]
+            n_curr = len(self[key]) # Current number of contacts
+            n_new = len(new_arr) # New contacts to add
+            n_total = n_curr + n_new # New size
+            self[key].resize(n_total, refcheck=False) # Resize to make room, preserving dtype
+            self[key][n_curr:] = new_arr # Copy contacts into the layer
+        return
+
+
     def to_df(self):
         ''' Convert to dataframe '''
         df = pd.DataFrame.from_dict(self)
@@ -1010,8 +1092,8 @@ class Layer(FlexDict):
 
 
     def from_df(self, df):
-        ''' Convert from dataframe '''
-        for key in self.meta.keys():
+        ''' Convert from a dataframe '''
+        for key in self.meta_keys():
             self[key] = df[key].to_numpy()
         return self
 
