@@ -29,9 +29,9 @@ class PeopleMeta(sc.prettyobj):
 
     # Set the properties of a person
     person = [
-        'uid',         # Any (int or str, usually)
+        'uid',         # Int
         'age',         # Float
-        'sex',         # Int
+        'sex',         # Float
         'symp_prob',   # Float
         'severe_prob', # Float
         'crit_prob',   # Float
@@ -185,20 +185,17 @@ def get_sim_plots(which='default'):
         plots = sc.odict({
                 'Total counts': [
                     'cum_infections',
-                    'cum_diagnoses',
-                    'cum_recoveries',
+                    'n_infectious',
                 ],
                 'Daily counts': [
                     'new_infections',
                     'new_diagnoses',
-                    'new_recoveries',
-                    'new_deaths',
                 ],
                 'Health outcomes': [
                     'cum_severe',
                     'cum_critical',
                     'cum_deaths',
-                ]
+                ],
         })
     elif which == 'overview':
         plots = sc.dcp(overview_plots)
@@ -215,12 +212,12 @@ def get_scen_plots(which='default'):
             'Cumulative infections': [
                 'cum_infections',
             ],
-            'Number of people currently infectious': [
-                'n_infectious',
+            'New infections per day': [
+                'new_infections',
+            ],
+            'Cumulative deaths': [
+                'cum_deaths',
             ],
-            'Number of people requiring hospitalization': [
-                'n_severe',
-            ]
         })
     elif which == 'overview':
         plots = sc.dcp(overview_plots)
