@@ -13,6 +13,7 @@ import datetime as dt
 import matplotlib.ticker as ticker
 import plotly.graph_objects as go
 from . import defaults as cvd
+from . import misc as cvm
 
 
 __all__ = ['plot_sim', 'plot_scens', 'plot_result', 'plot_compare', 'plotly_sim', 'plotly_people', 'plotly_animate']
@@ -32,7 +33,7 @@ def handle_args(fig_args=None, plot_args=None, scatter_args=None, axis_args=None
     args.show    = sc.mergedicts({'data':True, 'interventions':True, 'legend':True, }, show_args)
 
     # Handle what to show
-    show_keys = ['uncertainty', 'data', 'ticks', 'interventions', 'legend']
+    show_keys = ['data', 'ticks', 'interventions', 'legend']
     args.show = {k:True for k in show_keys}
     if show_args in [True, False]: # Handle all on or all off
         args.show = {k:show_args for k in show_keys}
@@ -64,9 +65,14 @@ def handle_to_plot(which, to_plot, n_cols, sim):
 
     to_plot = sc.odict(sc.dcp(to_plot)) # In case it's supplied as a dict
 
-    n_rows = np.ceil(len(to_plot)/n_cols) # Number of subplot rows to have
+    # Handle rows and columns -- assume 5 is the most rows we would want
+    n_plots = len(to_plot)
+    if n_cols is None:
+        max_rows = 4 # Assumption -- if desired, the user can override this by setting n_cols manually
+        n_cols = (n_plots-1)//max_rows + 1 # This gives 1 column for 1-4, 2 for 5-8, etc.
+    n_rows = np.ceil(n_plots/n_cols) # Number of subplot rows to have
 
-    return to_plot, n_rows
+    return to_plot, n_cols, n_rows
 
 
 def create_figs(args, font_size, font_family, sep_figs, fig=None):
@@ -191,21 +197,18 @@ def reset_ticks(ax, sim, interval, as_dates):
     return
 
 
-def tidy_up(fig, figs, sep_figs, do_save, fig_path, do_show, default_name='covasim.png'):
+def tidy_up(fig, figs, sep_figs, do_save, fig_path, do_show):
     ''' Handle saving, figure showing, and what value to return '''
 
     # Handle saving
     if do_save:
-        if fig_path is None: # No figpath provided - see whether do_save is a figpath
-            fig_path = default_name # Just give it a default name
-        fig_path = sc.makefilepath(fig_path) # Ensure it's valid, including creating the folder
-        pl.savefig(fig_path)
+        if fig_path is not None: # No figpath provided - see whether do_save is a figpath
+            fig_path = sc.makefilepath(fig_path) # Ensure it's valid, including creating the folder
+        cvm.savefig(filename=fig_path) # Save the figure
 
-    # Show or close the figure
+    # Show the figure
     if do_show:
         pl.show()
-    else:
-        pl.close(fig)
 
     # Return the figure or figures
     if sep_figs:
@@ -214,18 +217,31 @@ def tidy_up(fig, figs, sep_figs, do_save, fig_path, do_show, default_name='covas
         return fig
 
 
+def set_line_options(input_args, reskey, default):
+    '''From the supplied line argument, usually a color or label, decide what to use '''
+    if input_args is not None:
+        if isinstance(input_args, dict): # If it's a dict, pull out this value
+            output = input_args[reskey]
+        else: # Otherwise, assume it's the same value for all
+            output = input_args
+    else:
+        output = default # Default value
+    return output
+
+
+
 #%% Core plotting functions
 
 def plot_sim(sim, to_plot=None, do_save=None, fig_path=None, fig_args=None, plot_args=None,
          scatter_args=None, axis_args=None, fill_args=None, legend_args=None, show_args=None,
-         as_dates=True, dateformat=None, interval=None, n_cols=1, font_size=18, font_family=None,
+         as_dates=True, dateformat=None, interval=None, n_cols=None, font_size=18, font_family=None,
          grid=False, commaticks=True, setylim=True, log_scale=False, colors=None, labels=None,
          do_show=True, sep_figs=False, fig=None):
     ''' Plot the results of a single simulation -- see Sim.plot() for documentation '''
 
     # Handle inputs
     args = handle_args(fig_args, plot_args, scatter_args, axis_args, fill_args, legend_args, show_args)
-    to_plot, n_rows = handle_to_plot('sim', to_plot, n_cols, sim=sim)
+    to_plot, n_cols, n_rows = handle_to_plot('sim', to_plot, n_cols, sim=sim)
     fig, figs, ax = create_figs(args, font_size, font_family, sep_figs, fig)
 
     # Do the plotting
@@ -234,15 +250,9 @@ def plot_sim(sim, to_plot=None, do_save=None, fig_path=None, fig_args=None, plot
         for reskey in keylabels:
             res = sim.results[reskey]
             res_t = sim.results['t']
-            if colors is not None:
-                color = colors[reskey]
-            else:
-                color = res.color
-            if labels is not None:
-                label = labels[reskey]
-            else:
-                label = res.name
-            if res.low is not None and res.high is not None and args.show['uncertainty']:
+            color = set_line_options(colors, reskey, res.color) # Choose the color
+            label = set_line_options(labels, reskey, res.name) # Choose the label
+            if res.low is not None and res.high is not None:
                 ax.fill_between(res_t, res.low, res.high, color=color, **args.fill) # Create the uncertainty bound
             ax.plot(res_t, res.values, label=label, **args.plot, c=color) # Actually plot the sim!
             if args.show['data']:
@@ -254,19 +264,19 @@ def plot_sim(sim, to_plot=None, do_save=None, fig_path=None, fig_args=None, plot
         if args.show['legend']:
             title_grid_legend(ax, title, grid, commaticks, setylim, args.legend) # Configure the title, grid, and legend
 
-    return tidy_up(fig, figs, sep_figs, do_save, fig_path, do_show, default_name='covasim.png')
+    return tidy_up(fig, figs, sep_figs, do_save, fig_path, do_show)
 
 
 def plot_scens(scens, to_plot=None, do_save=None, fig_path=None, fig_args=None, plot_args=None,
          scatter_args=None, axis_args=None, fill_args=None, legend_args=None, show_args=None,
-         as_dates=True, dateformat=None, interval=None, n_cols=1, font_size=18, font_family=None,
+         as_dates=True, dateformat=None, interval=None, n_cols=None, font_size=18, font_family=None,
          grid=False, commaticks=True, setylim=True, log_scale=False, colors=None, labels=None,
          do_show=True, sep_figs=False, fig=None):
     ''' Plot the results of a scenario -- see Scenarios.plot() for documentation '''
 
     # Handle inputs
     args = handle_args(fig_args, plot_args, scatter_args, axis_args, fill_args, legend_args)
-    to_plot, n_rows = handle_to_plot('scens', to_plot, n_cols, sim=scens.base_sim)
+    to_plot, n_cols, n_rows = handle_to_plot('scens', to_plot, n_cols, sim=scens.base_sim)
     fig, figs, ax = create_figs(args, font_size, font_family, sep_figs, fig)
 
     # Do the plotting
@@ -279,16 +289,9 @@ def plot_scens(scens, to_plot=None, do_save=None, fig_path=None, fig_args=None,
             for snum,scenkey,scendata in resdata.enumitems():
                 sim = scens.sims[scenkey][0] # Pull out the first sim in the list for this scenario
                 res_y = scendata.best
-                if colors is not None:
-                    color = colors[scenkey]
-                else:
-                    color = default_colors[snum]
-                if labels is not None:
-                    label = labels[scenkey]
-                else:
-                    label = scendata.name
-                if args.show['uncertainty']:
-                    ax.fill_between(scens.tvec, scendata.low, scendata.high, color=color, **args.fill) # Create the uncertainty bound
+                color = set_line_options(colors, scenkey, default_colors[snum]) # Choose the color
+                label = set_line_options(labels, scenkey, scendata.name) # Choose the label
+                ax.fill_between(scens.tvec, scendata.low, scendata.high, color=color, **args.fill) # Create the uncertainty bound
                 ax.plot(scens.tvec, res_y, label=label, c=color, **args.plot) # Plot the actual line
                 if args.show['data']:
                     plot_data(sim, ax, reskey, args.scatter) # Plot the data
@@ -299,7 +302,7 @@ def plot_scens(scens, to_plot=None, do_save=None, fig_path=None, fig_args=None,
         if args.show['legend']:
             title_grid_legend(ax, title, grid, commaticks, setylim, args.legend, pnum==0) # Configure the title, grid, and legend -- only show legend for first
 
-    return tidy_up(fig, figs, sep_figs, do_save, fig_path, do_show, default_name='covasim_scenarios.png')
+    return tidy_up(fig, figs, sep_figs, do_save, fig_path, do_show)
 
 
 def plot_result(sim, key, fig_args=None, plot_args=None, axis_args=None, scatter_args=None,
